﻿Imports System
Imports System.Collections.Generic
Imports System.Linq
Imports System.Text
Imports MPEIVILib
Imports Ivi.DCPwr.Interop
Imports Ivi.Driver.Interop

Namespace MPE_IVI_Driver_Example
    Class Program
        Public Shared Sub Main(ByVal args As String())
            Try
                Dim driver As IMPEIVI = Nothing
                Try
                    driver = New MPEIVI()
                Catch ex As Exception
                    Console.WriteLine("Error creating driver object. Ensure IVI driver is installed.")
                    Console.WriteLine("Exception Details: " & ex.ToString())
                    Exit Sub
                End Try

                Try

                    'output basic driver information
                    Console.WriteLine("Identifier: {0}", driver.Identity.Identifier)
                    Console.WriteLine("Revision: {0}", driver.Identity.Revision)
                    Console.WriteLine("Vendor: {0}", driver.Identity.Vendor)
                    Console.WriteLine("Description: {0}", driver.Identity.Description)

                    ' Setup VISA resource descriptor - how the driver will connect to the power supply.

                    'Examples of other valid VISA resource descriptors
                    '"TCPIP::MPE12345678::50505::SOCKET"; //NETBIOS name direct to TCP port
                    '"TCPIP::MPE12345678::inst0::INSTR"; //NETBIOS name to VXI (via UDP and TCP port 111)
                    '"TCPIP::192.168.1.100::50505::SOCKET"; //IP address direct to TCP port
                    '"GPIB0::13::INSTR"; //GPIB address 13
                    '"ASRL1"; //COM Port 1


                    Dim resourceDesc As String = "TCPIP::MPE00000361::50505::SOCKET"


                    ' Setup IVI-defined initialization options
                    Dim standardInitOptions As String = "Cache=true, InterchangeCheck=false, QueryInstrStatus=true, RangeCheck=true, RecordCoercions=false, Simulate=false"

                    ' Setup driver-specific initialization options
                    Dim driverSetupOptions As String = "DriverSetup= Model=MPEIVI, Trace=false"

                    Console.WriteLine("Connecting to Power Supply...")
                    driver.Initialize(resourceDesc, True, False, (standardInitOptions & ",") + driverSetupOptions)
                Catch ex As Exception
                    Console.WriteLine("Error initializing driver.")
                    Console.WriteLine("Ensure resource descriptor is correct and power supply is on.")
                    Console.WriteLine("Exception Message:" & ex.Message)
                    Exit Sub
                End Try


                Try
                    'Retrieve the name of the only output of the power supply
                    Dim outputName As String = driver.Outputs.Name(1)


                    'There are two interfaces for accessing the power supply
                    'IIviDCPwrOutput and IMPEIVIOutput.
                    '
                    'The IVI DCPwr interface can be used to access all of the standard IVI-defined functions
                    'The MPE interface allows access to the full functionality of the power supply.

                    Dim mpeOutput As IMPEIVIOutput = TryCast(driver.Outputs.Item(outputName), IMPEIVIOutput)
                    Dim iviOutput As IIviDCPwrOutput = mpeOutput

                    Console.WriteLine("Making sure Power supply is in remote mode.")
                    Dim origSetPoint As MPEIVISetpointEnum = mpeOutput.Setpoint

                    'Make sure the power supply is off
                    mpeOutput.Enabled = False

                    'Ensure the setpoint is Remote
                    mpeOutput.Setpoint = MPEIVISetpointEnum.MPEIVISetpointRemote


                    'issue a *RST
                    TryCast(driver, IIviDriverUtility).Reset()

                    'Retrieve the IDN string
                    Dim idn As String = mpeOutput.GetIDN()
                    Console.WriteLine(idn)

                    'Retrieve the current and voltage scale
                    Dim currScale As Double = mpeOutput.CalGetCurrentScale()
                    'equivalent to QueryCurrentLimitMax()
                    Dim voltScale As Double = mpeOutput.CalGetVoltageScale()
                    'equivalent to QueryVoltageLimitMax()
                    Console.WriteLine("Max voltage: " & voltScale)



                    Console.WriteLine("Max current: " & currScale)
                Catch ex As Exception

                    Console.WriteLine(vbTab & ex.Message)
                    Dim errorNum As Integer = -1
                    Dim errorMsg As String = Nothing
                    Console.WriteLine("")
                    While errorNum <> 0
                        driver.Utility.ErrorQuery(errorNum, errorMsg)
                        Console.WriteLine(vbTab & "ErrorQuery: {0}, {1}", errorNum, errorMsg)

                    End While
                End Try
            Finally
                Console.WriteLine("Press Enter key to exit.")
                Console.ReadLine()
            End Try
        End Sub
    End Class
End Namespace